Access KGS server and download the latest rank graph of the specified player.
Requires internet connection.
Returns the path to the downloaded file if succeeded.
Usage
download_graph(id, dst = tempfile(), lang = "en", country = "US",
method = "libcurl", ...)
Arguments
id
KGS ID
dst
destination file path or directory
lang
language code, a lower case character of length 2
country
country code, an upper case character of length 2
method
method to be used for downloading files. See download.file for details
...
optional arguments for download.file other than
method and mode
Value
path to the saved file
Details
Default setting downloads the English version. Another good option is
to set lang='ja' and country='JP', which downloads the Japanese version.